@@ -121,8 +121,8 @@ sub database_setting {
             if ( $group eq 'reset_db_dummy_str' ) {
                 my $tu = Term::Choose::Util->new( $sf->{i}{tcu_default} );
                 my @databases;
-                for my $key ( keys %$db_opt ) {
-                    push @databases, $key if $key ne $plugin;
+                for my $key_local ( keys %$db_opt ) {
+                    push @databases, $key_local if $key_local ne $plugin;
                 }
                 if ( ! @databases ) {
                     $tc->choose(
@@ -133,7 +133,8 @@ sub database_setting {
                 }
                 my $db_to_reset = $tu->choose_a_subset(
                     [ sort @databases ],
-                    { cs_label => 'DB settings to reset: ', layout => 2, cs_separator => "\n", cs_begin => "\n", prompt => "\nChoose:" }
+                    { cs_label => 'DB settings to reset: ', layout => 2, cs_separator => "\n", cs_begin => "\n",
+                      prompt => "\nChoose:", confirm => $sf->{i}{confirm}, back => $sf->{i}{back} }
                 );
                 if ( ! $db_to_reset->[0] ) {
                     next GROUP;
