@@ -95,8 +95,8 @@ sub defaults {
             enable_input_filter      => 0,
             empty_to_null_plain      => 1,
             empty_to_null_file       => 1,
-            data_source_Create_table => 2,
-            data_source_Insert       => 2,
+            data_source_create_table => 2,
+            data_source_insert       => 2,
             show_hidden_files        => 0,
             file_filter              => '',
         },
